/****************************************************************************
** Meta object code from reading C++ file 'MainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../btrfs-assistant-2.2/src/ui/MainWindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "on_checkBox_bmBalance_clicked",
        "",
        "checked",
        "on_checkBox_bmDefrag_clicked",
        "on_checkBox_bmScrub_clicked",
        "on_checkBox_snapperEnableTimeline_clicked",
        "on_comboBox_btrfsDevice_activated",
        "index",
        "on_comboBox_snapperConfigs_activated",
        "on_comboBox_snapperConfigSettings_activated",
        "on_comboBox_snapperSubvols_activated",
        "on_pushButton_btrfsRefreshData_clicked",
        "on_pushButton_btrfsBalance_clicked",
        "on_pushButton_btrfsScrub_clicked",
        "on_pushButton_enableQuota_clicked",
        "on_pushButton_snapperDeleteConfig_clicked",
        "on_pushButton_snapperNewConfig_clicked",
        "on_pushButton_snapperSaveConfig_clicked",
        "on_pushButton_snapperUnitsApply_clicked",
        "on_tableView_subvols_customContextMenuRequested",
        "QPoint",
        "pos",
        "on_tableWidget_snapperNew_customContextMenuRequested",
        "on_tabWidget_mainWindow_currentChanged",
        "on_toolButton_bmApply_clicked",
        "on_toolButton_bmReset_clicked",
        "on_toolButton_snapperNewRefresh_clicked",
        "on_toolButton_snapperRestore_clicked",
        "on_toolButton_snapperBrowse_clicked",
        "on_toolButton_snapperCreate_clicked",
        "on_toolButton_snapperDelete_clicked",
        "snapperChangeDescription",
        "on_toolButton_snapperRestoreRefresh_clicked",
        "on_toolButton_subvolRestoreBackup_clicked",
        "on_toolButton_subvolRefresh_clicked",
        "on_toolButton_subvolumeBrowse_clicked",
        "on_toolButton_subvolDelete_clicked",
        "subvolsSelectionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'on_checkBox_bmBalance_clicked'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'on_checkBox_bmDefrag_clicked'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'on_checkBox_bmScrub_clicked'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'on_checkBox_snapperEnableTimeline_clicked'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'on_comboBox_btrfsDevice_activated'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'on_comboBox_snapperConfigs_activated'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'on_comboBox_snapperConfigSettings_activated'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'on_comboBox_snapperSubvols_activated'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'on_pushButton_btrfsRefreshData_clicked'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pushButton_btrfsBalance_clicked'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pushButton_btrfsScrub_clicked'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pushButton_enableQuota_clicked'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pushButton_snapperDeleteConfig_clicked'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pushButton_snapperNewConfig_clicked'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pushButton_snapperSaveConfig_clicked'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_pushButton_snapperUnitsApply_clicked'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_tableView_subvols_customContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'on_tableWidget_snapperNew_customContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'on_tabWidget_mainWindow_currentChanged'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_bmApply_clicked'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_bmReset_clicked'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_snapperNewRefresh_clicked'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_snapperRestore_clicked'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_snapperBrowse_clicked'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_snapperCreate_clicked'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_snapperDelete_clicked'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'snapperChangeDescription'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_snapperRestoreRefresh_clicked'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_subvolRestoreBackup_clicked'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_subvolRefresh_clicked'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_subvolumeBrowse_clicked'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'on_toolButton_subvolDelete_clicked'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'subvolsSelectionChanged'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->on_checkBox_bmBalance_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->on_checkBox_bmDefrag_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->on_checkBox_bmScrub_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->on_checkBox_snapperEnableTimeline_clicked((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->on_comboBox_btrfsDevice_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->on_comboBox_snapperConfigs_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->on_comboBox_snapperConfigSettings_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->on_comboBox_snapperSubvols_activated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->on_pushButton_btrfsRefreshData_clicked(); break;
        case 9: _t->on_pushButton_btrfsBalance_clicked(); break;
        case 10: _t->on_pushButton_btrfsScrub_clicked(); break;
        case 11: _t->on_pushButton_enableQuota_clicked(); break;
        case 12: _t->on_pushButton_snapperDeleteConfig_clicked(); break;
        case 13: _t->on_pushButton_snapperNewConfig_clicked(); break;
        case 14: _t->on_pushButton_snapperSaveConfig_clicked(); break;
        case 15: _t->on_pushButton_snapperUnitsApply_clicked(); break;
        case 16: _t->on_tableView_subvols_customContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 17: _t->on_tableWidget_snapperNew_customContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 18: _t->on_tabWidget_mainWindow_currentChanged(); break;
        case 19: _t->on_toolButton_bmApply_clicked(); break;
        case 20: _t->on_toolButton_bmReset_clicked(); break;
        case 21: _t->on_toolButton_snapperNewRefresh_clicked(); break;
        case 22: _t->on_toolButton_snapperRestore_clicked(); break;
        case 23: _t->on_toolButton_snapperBrowse_clicked(); break;
        case 24: _t->on_toolButton_snapperCreate_clicked(); break;
        case 25: _t->on_toolButton_snapperDelete_clicked(); break;
        case 26: _t->snapperChangeDescription(); break;
        case 27: _t->on_toolButton_snapperRestoreRefresh_clicked(); break;
        case 28: _t->on_toolButton_subvolRestoreBackup_clicked(); break;
        case 29: _t->on_toolButton_subvolRefresh_clicked(); break;
        case 30: _t->on_toolButton_subvolumeBrowse_clicked(); break;
        case 31: _t->on_toolButton_subvolDelete_clicked(); break;
        case 32: _t->subvolsSelectionChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 33;
    }
    return _id;
}
QT_WARNING_POP
