/********************************************************************************
** Form generated from reading UI file 'MainWindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "widgets/FilterLineEdit.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QWidget *centralwidget;
    QGridLayout *gridLayout;
    QTabWidget *tabWidget_mainWindow;
    QWidget *tab_btrfs;
    QGridLayout *gridLayout_33;
    QScrollArea *scrollArea_btrfs;
    QWidget *scrollAreaWidgetContents_4;
    QGridLayout *gridLayout_7;
    QGroupBox *groupBox_btrfsSrubOperation;
    QGridLayout *gridLayout_9;
    QSpacerItem *horizontalSpacer_22;
    QSpacerItem *horizontalSpacer_20;
    QPushButton *pushButton_btrfsScrub;
    QLabel *label_btrfsScrubStatus;
    QGroupBox *groupBox_btrfsBalanceOperation;
    QGridLayout *gridLayout_8;
    QSpacerItem *horizontalSpacer_18;
    QSpacerItem *horizontalSpacer_17;
    QPushButton *pushButton_btrfsBalance;
    QLabel *label_btrfsBalanceStatus;
    QGroupBox *groupBox_btrfsFilesystemStats;
    QGridLayout *gridLayout_35;
    QProgressBar *progressBar_btrfssys;
    QLabel *label_btrfsdata;
    QLabel *label_btrfsmeta;
    QLabel *label_btrfssys;
    QProgressBar *progressBar_btrfsmeta;
    QProgressBar *progressBar_btrfsdata;
    QGroupBox *groupBox_btrfsInfo;
    QGridLayout *gridLayout_22;
    QLabel *label_btrfsUsed;
    QLabel *label_btrfsFreeValue;
    QLabel *label_btrfsFreeMinValue;
    QLabel *label_btrfsUsedValue;
    QLabel *label_btrfsAllocatedValue;
    QLabel *label_btrfsAllocated;
    QLabel *label_btrfsSizeValue;
    QLabel *label_btrfsSize;
    QLabel *label_btrfsMessage;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_btrfsFree;
    QLabel *label_btrfsFreeMin;
    QGroupBox *groupBox_deviceSelection;
    QHBoxLayout *horizontalLayout;
    QLabel *label_btrfsDevice;
    QComboBox *comboBox_btrfsDevice;
    QSpacerItem *horizontalSpacer_7;
    QPushButton *pushButton_enableQuota;
    QPushButton *pushButton_btrfsRefreshData;
    QWidget *tab_subvolumes;
    QGridLayout *gridLayout_3;
    QScrollArea *scrollArea_subvolumes;
    QWidget *scrollAreaWidgetContents_2;
    QGridLayout *gridLayout_10;
    QHBoxLayout *horizontalLayout_includeSubvolumes;
    QCheckBox *checkBox_subvolIncludeSnapshots;
    QCheckBox *checkBox_subvolIncludeContainer;
    QFrame *frame_subvolumesOptions;
    QHBoxLayout *horizontalLayout_9;
    FilterLineEdit *lineEdit_subvolFilter;
    QSpacerItem *horizontalSpacer_9;
    QToolButton *toolButton_subvolRestoreBackup;
    QToolButton *toolButton_subvolumeBrowse;
    QToolButton *toolButton_subvolDelete;
    QToolButton *toolButton_subvolRefresh;
    QTableView *tableView_subvols;
    QWidget *tab_snapper_general;
    QGridLayout *gridLayout_25;
    QTabWidget *tabWidget_snapper;
    QWidget *tab_snapperNew;
    QVBoxLayout *verticalLayout_4;
    QFrame *frame_7;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_snapperSelect;
    QComboBox *comboBox_snapperConfigs;
    QSpacerItem *horizontalSpacer_8;
    QToolButton *toolButton_snapperCreate;
    QToolButton *toolButton_snapperDelete;
    QToolButton *toolButton_snapperNewRefresh;
    QTableWidget *tableWidget_snapperNew;
    QWidget *tab_snapperRestore;
    QVBoxLayout *verticalLayout_5;
    QFrame *frame;
    QHBoxLayout *horizontalLayout_8;
    QLabel *label_snapperSubvol;
    QComboBox *comboBox_snapperSubvols;
    QSpacerItem *horizontalSpacer_6;
    QToolButton *toolButton_snapperBrowse;
    QToolButton *toolButton_snapperRestore;
    QToolButton *toolButton_snapperRestoreRefresh;
    QTableWidget *tableWidget_snapperRestore;
    QWidget *tab_snapper_settings;
    QGridLayout *gridLayout_26;
    QScrollArea *scrollArea_snapperSettings;
    QWidget *scrollAreaWidgetContents_6;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_snapperConfigCrud;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_6;
    QComboBox *comboBox_snapperConfigSettings;
    QSpacerItem *horizontalSpacer_10;
    QPushButton *pushButton_snapperNewConfig;
    QPushButton *pushButton_snapperDeleteConfig;
    QSpacerItem *horizontalSpacer_11;
    QPushButton *pushButton_snapperSaveConfig;
    QGroupBox *groupBox_snapperConfigDisplay;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_snapperConfigName;
    QLabel *label_snapperConfigNameValue;
    QSpacerItem *horizontalSpacer_12;
    QLabel *label_snapperBackupPath;
    QLabel *label_snapperBackupPathValue;
    QSpacerItem *horizontalSpacer_13;
    QGroupBox *groupBox_snapperConfigCreate;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_snapperName;
    QLineEdit *lineEdit_snapperName;
    QSpacerItem *horizontalSpacer_14;
    QLabel *label_backupPath;
    QComboBox *comboBox_snapperPath;
    QSpacerItem *horizontalSpacer_15;
    QGroupBox *groupBox_snapperConfigSettings;
    QGridLayout *gridLayout_27;
    QLabel *label_snapperSave4;
    QSpinBox *spinBox_snapperYearly;
    QSpinBox *spinBox_snapperHourly;
    QLabel *label_snapperEnableTimeline;
    QLabel *label_snapperSave3;
    QLabel *label_snapperDaily;
    QLabel *label_snapperSave2;
    QLabel *label_snapperSave5;
    QCheckBox *checkBox_snapperEnableTimeline;
    QSpinBox *spinBox_snapperWeekly;
    QSpinBox *spinBox_snapperDaily;
    QSpinBox *spinBox_snapperMonthly;
    QLabel *label_snapperYearly;
    QLabel *label_snapperMonthly;
    QSpinBox *spinBox_snapperNumber;
    QLabel *label_snapperHourly;
    QLabel *label_snapperWeekly;
    QLabel *label_snapperSave6;
    QLabel *label_snapperNumber;
    QLabel *label_snapperSave1;
    QSpacerItem *horizontalSpacer_16;
    QGroupBox *groupBox_snapperUnits;
    QHBoxLayout *horizontalLayout_6;
    QCheckBox *checkBox_snapperTimeline;
    QCheckBox *checkBox_snapperCleanup;
    QCheckBox *checkBox_snapperBoot;
    QPushButton *pushButton_snapperUnitsApply;
    QGroupBox *groupBox_2;
    QWidget *tab_btrfsmaintenance;
    QGridLayout *gridLayout_2;
    QScrollArea *scrollArea_bm;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox_bmBalance;
    QGridLayout *gridLayout_4;
    QSpacerItem *horizontalSpacer;
    QLabel *label_bmBalanceFreq;
    QComboBox *comboBox_bmBalanceFreq;
    QCheckBox *checkBox_bmBalance;
    QLabel *label_bmBalanceSubvols;
    QListWidget *listWidget_bmBalance;
    QGroupBox *groupBox_bmScrub;
    QGridLayout *gridLayout_5;
    QComboBox *comboBox_bmScrubFreq;
    QSpacerItem *horizontalSpacer_2;
    QListWidget *listWidget_bmScrub;
    QLabel *label_bmScrubFreq;
    QCheckBox *checkBox_bmScrub;
    QLabel *label_bmScrubSubvols;
    QGroupBox *groupBox_bmDefrag;
    QGridLayout *gridLayout_6;
    QComboBox *comboBox_bmDefragFreq;
    QListWidget *listWidget_bmDefrag;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_bmDefragFreq;
    QCheckBox *checkBox_bmDefrag;
    QLabel *label_bmScrubSubvols_2;
    QFrame *frame_bmApply;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_4;
    QToolButton *toolButton_bmReset;
    QToolButton *toolButton_bmApply;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        MainWindow->resize(946, 717);
        centralwidget = new QWidget(MainWindow);
        centralwidget->setObjectName("centralwidget");
        gridLayout = new QGridLayout(centralwidget);
        gridLayout->setObjectName("gridLayout");
        tabWidget_mainWindow = new QTabWidget(centralwidget);
        tabWidget_mainWindow->setObjectName("tabWidget_mainWindow");
        tabWidget_mainWindow->setMinimumSize(QSize(100, 0));
        tab_btrfs = new QWidget();
        tab_btrfs->setObjectName("tab_btrfs");
        gridLayout_33 = new QGridLayout(tab_btrfs);
        gridLayout_33->setObjectName("gridLayout_33");
        gridLayout_33->setContentsMargins(0, 0, 0, 0);
        scrollArea_btrfs = new QScrollArea(tab_btrfs);
        scrollArea_btrfs->setObjectName("scrollArea_btrfs");
        scrollArea_btrfs->setFrameShape(QFrame::NoFrame);
        scrollArea_btrfs->setWidgetResizable(true);
        scrollAreaWidgetContents_4 = new QWidget();
        scrollAreaWidgetContents_4->setObjectName("scrollAreaWidgetContents_4");
        scrollAreaWidgetContents_4->setGeometry(QRect(0, 0, 924, 668));
        gridLayout_7 = new QGridLayout(scrollAreaWidgetContents_4);
        gridLayout_7->setObjectName("gridLayout_7");
        groupBox_btrfsSrubOperation = new QGroupBox(scrollAreaWidgetContents_4);
        groupBox_btrfsSrubOperation->setObjectName("groupBox_btrfsSrubOperation");
        groupBox_btrfsSrubOperation->setAlignment(Qt::AlignCenter);
        gridLayout_9 = new QGridLayout(groupBox_btrfsSrubOperation);
        gridLayout_9->setObjectName("gridLayout_9");
        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacer_22, 1, 2, 1, 1);

        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_9->addItem(horizontalSpacer_20, 1, 0, 1, 1);

        pushButton_btrfsScrub = new QPushButton(groupBox_btrfsSrubOperation);
        pushButton_btrfsScrub->setObjectName("pushButton_btrfsScrub");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pushButton_btrfsScrub->sizePolicy().hasHeightForWidth());
        pushButton_btrfsScrub->setSizePolicy(sizePolicy);

        gridLayout_9->addWidget(pushButton_btrfsScrub, 1, 1, 1, 1);

        label_btrfsScrubStatus = new QLabel(groupBox_btrfsSrubOperation);
        label_btrfsScrubStatus->setObjectName("label_btrfsScrubStatus");
        QFont font;
        font.setFamilies({QString::fromUtf8("Bitstream Vera Sans Mono")});
        font.setPointSize(10);
        font.setBold(false);
        font.setItalic(false);
        label_btrfsScrubStatus->setFont(font);
        label_btrfsScrubStatus->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        label_btrfsScrubStatus->setWordWrap(true);
        label_btrfsScrubStatus->setMargin(0);

        gridLayout_9->addWidget(label_btrfsScrubStatus, 0, 0, 1, 3);


        gridLayout_7->addWidget(groupBox_btrfsSrubOperation, 7, 0, 1, 1);

        groupBox_btrfsBalanceOperation = new QGroupBox(scrollAreaWidgetContents_4);
        groupBox_btrfsBalanceOperation->setObjectName("groupBox_btrfsBalanceOperation");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox_btrfsBalanceOperation->sizePolicy().hasHeightForWidth());
        groupBox_btrfsBalanceOperation->setSizePolicy(sizePolicy1);
        groupBox_btrfsBalanceOperation->setAlignment(Qt::AlignCenter);
        gridLayout_8 = new QGridLayout(groupBox_btrfsBalanceOperation);
        gridLayout_8->setObjectName("gridLayout_8");
        horizontalSpacer_18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_8->addItem(horizontalSpacer_18, 1, 2, 1, 1);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_8->addItem(horizontalSpacer_17, 1, 0, 1, 1);

        pushButton_btrfsBalance = new QPushButton(groupBox_btrfsBalanceOperation);
        pushButton_btrfsBalance->setObjectName("pushButton_btrfsBalance");
        sizePolicy.setHeightForWidth(pushButton_btrfsBalance->sizePolicy().hasHeightForWidth());
        pushButton_btrfsBalance->setSizePolicy(sizePolicy);

        gridLayout_8->addWidget(pushButton_btrfsBalance, 1, 1, 1, 1);

        label_btrfsBalanceStatus = new QLabel(groupBox_btrfsBalanceOperation);
        label_btrfsBalanceStatus->setObjectName("label_btrfsBalanceStatus");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_btrfsBalanceStatus->sizePolicy().hasHeightForWidth());
        label_btrfsBalanceStatus->setSizePolicy(sizePolicy2);
        QFont font1;
        font1.setFamilies({QString::fromUtf8("Bitstream Vera Sans Mono")});
        font1.setPointSize(10);
        label_btrfsBalanceStatus->setFont(font1);
        label_btrfsBalanceStatus->setWordWrap(true);
        label_btrfsBalanceStatus->setMargin(0);

        gridLayout_8->addWidget(label_btrfsBalanceStatus, 0, 0, 1, 3);


        gridLayout_7->addWidget(groupBox_btrfsBalanceOperation, 7, 1, 1, 1);

        groupBox_btrfsFilesystemStats = new QGroupBox(scrollAreaWidgetContents_4);
        groupBox_btrfsFilesystemStats->setObjectName("groupBox_btrfsFilesystemStats");
        sizePolicy2.setHeightForWidth(groupBox_btrfsFilesystemStats->sizePolicy().hasHeightForWidth());
        groupBox_btrfsFilesystemStats->setSizePolicy(sizePolicy2);
        gridLayout_35 = new QGridLayout(groupBox_btrfsFilesystemStats);
        gridLayout_35->setObjectName("gridLayout_35");
        progressBar_btrfssys = new QProgressBar(groupBox_btrfsFilesystemStats);
        progressBar_btrfssys->setObjectName("progressBar_btrfssys");
        progressBar_btrfssys->setValue(0);

        gridLayout_35->addWidget(progressBar_btrfssys, 2, 1, 1, 1);

        label_btrfsdata = new QLabel(groupBox_btrfsFilesystemStats);
        label_btrfsdata->setObjectName("label_btrfsdata");

        gridLayout_35->addWidget(label_btrfsdata, 0, 0, 1, 1);

        label_btrfsmeta = new QLabel(groupBox_btrfsFilesystemStats);
        label_btrfsmeta->setObjectName("label_btrfsmeta");

        gridLayout_35->addWidget(label_btrfsmeta, 1, 0, 1, 1);

        label_btrfssys = new QLabel(groupBox_btrfsFilesystemStats);
        label_btrfssys->setObjectName("label_btrfssys");

        gridLayout_35->addWidget(label_btrfssys, 2, 0, 1, 1);

        progressBar_btrfsmeta = new QProgressBar(groupBox_btrfsFilesystemStats);
        progressBar_btrfsmeta->setObjectName("progressBar_btrfsmeta");
        progressBar_btrfsmeta->setValue(0);

        gridLayout_35->addWidget(progressBar_btrfsmeta, 1, 1, 1, 1);

        progressBar_btrfsdata = new QProgressBar(groupBox_btrfsFilesystemStats);
        progressBar_btrfsdata->setObjectName("progressBar_btrfsdata");
        progressBar_btrfsdata->setValue(0);

        gridLayout_35->addWidget(progressBar_btrfsdata, 0, 1, 1, 1);


        gridLayout_7->addWidget(groupBox_btrfsFilesystemStats, 6, 0, 1, 2);

        groupBox_btrfsInfo = new QGroupBox(scrollAreaWidgetContents_4);
        groupBox_btrfsInfo->setObjectName("groupBox_btrfsInfo");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(groupBox_btrfsInfo->sizePolicy().hasHeightForWidth());
        groupBox_btrfsInfo->setSizePolicy(sizePolicy3);
        gridLayout_22 = new QGridLayout(groupBox_btrfsInfo);
        gridLayout_22->setObjectName("gridLayout_22");
        label_btrfsUsed = new QLabel(groupBox_btrfsInfo);
        label_btrfsUsed->setObjectName("label_btrfsUsed");

        gridLayout_22->addWidget(label_btrfsUsed, 2, 0, 1, 1, Qt::AlignLeft);

        label_btrfsFreeValue = new QLabel(groupBox_btrfsInfo);
        label_btrfsFreeValue->setObjectName("label_btrfsFreeValue");

        gridLayout_22->addWidget(label_btrfsFreeValue, 3, 1, 1, 1);

        label_btrfsFreeMinValue = new QLabel(groupBox_btrfsInfo);
        label_btrfsFreeMinValue->setObjectName("label_btrfsFreeMinValue");

        gridLayout_22->addWidget(label_btrfsFreeMinValue, 4, 1, 1, 1);

        label_btrfsUsedValue = new QLabel(groupBox_btrfsInfo);
        label_btrfsUsedValue->setObjectName("label_btrfsUsedValue");

        gridLayout_22->addWidget(label_btrfsUsedValue, 2, 1, 1, 1);

        label_btrfsAllocatedValue = new QLabel(groupBox_btrfsInfo);
        label_btrfsAllocatedValue->setObjectName("label_btrfsAllocatedValue");

        gridLayout_22->addWidget(label_btrfsAllocatedValue, 1, 1, 1, 1, Qt::AlignLeft);

        label_btrfsAllocated = new QLabel(groupBox_btrfsInfo);
        label_btrfsAllocated->setObjectName("label_btrfsAllocated");

        gridLayout_22->addWidget(label_btrfsAllocated, 1, 0, 1, 1, Qt::AlignLeft);

        label_btrfsSizeValue = new QLabel(groupBox_btrfsInfo);
        label_btrfsSizeValue->setObjectName("label_btrfsSizeValue");

        gridLayout_22->addWidget(label_btrfsSizeValue, 0, 1, 1, 1);

        label_btrfsSize = new QLabel(groupBox_btrfsInfo);
        label_btrfsSize->setObjectName("label_btrfsSize");

        gridLayout_22->addWidget(label_btrfsSize, 0, 0, 1, 1, Qt::AlignLeft);

        label_btrfsMessage = new QLabel(groupBox_btrfsInfo);
        label_btrfsMessage->setObjectName("label_btrfsMessage");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(3);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(label_btrfsMessage->sizePolicy().hasHeightForWidth());
        label_btrfsMessage->setSizePolicy(sizePolicy4);

        gridLayout_22->addWidget(label_btrfsMessage, 5, 1, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_22->addItem(horizontalSpacer_5, 1, 3, 1, 1);

        label_btrfsFree = new QLabel(groupBox_btrfsInfo);
        label_btrfsFree->setObjectName("label_btrfsFree");

        gridLayout_22->addWidget(label_btrfsFree, 3, 0, 1, 1, Qt::AlignLeft);

        label_btrfsFreeMin = new QLabel(groupBox_btrfsInfo);
        label_btrfsFreeMin->setObjectName("label_btrfsFreeMin");

        gridLayout_22->addWidget(label_btrfsFreeMin, 4, 0, 1, 1, Qt::AlignLeft);


        gridLayout_7->addWidget(groupBox_btrfsInfo, 4, 0, 1, 2);

        groupBox_deviceSelection = new QGroupBox(scrollAreaWidgetContents_4);
        groupBox_deviceSelection->setObjectName("groupBox_deviceSelection");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(groupBox_deviceSelection->sizePolicy().hasHeightForWidth());
        groupBox_deviceSelection->setSizePolicy(sizePolicy5);
        horizontalLayout = new QHBoxLayout(groupBox_deviceSelection);
        horizontalLayout->setObjectName("horizontalLayout");
        label_btrfsDevice = new QLabel(groupBox_deviceSelection);
        label_btrfsDevice->setObjectName("label_btrfsDevice");

        horizontalLayout->addWidget(label_btrfsDevice);

        comboBox_btrfsDevice = new QComboBox(groupBox_deviceSelection);
        comboBox_btrfsDevice->setObjectName("comboBox_btrfsDevice");
        comboBox_btrfsDevice->setEditable(false);
        comboBox_btrfsDevice->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout->addWidget(comboBox_btrfsDevice);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_7);

        pushButton_enableQuota = new QPushButton(groupBox_deviceSelection);
        pushButton_enableQuota->setObjectName("pushButton_enableQuota");

        horizontalLayout->addWidget(pushButton_enableQuota);

        pushButton_btrfsRefreshData = new QPushButton(groupBox_deviceSelection);
        pushButton_btrfsRefreshData->setObjectName("pushButton_btrfsRefreshData");

        horizontalLayout->addWidget(pushButton_btrfsRefreshData);


        gridLayout_7->addWidget(groupBox_deviceSelection, 1, 0, 1, 2);

        scrollArea_btrfs->setWidget(scrollAreaWidgetContents_4);

        gridLayout_33->addWidget(scrollArea_btrfs, 0, 0, 1, 1);

        tabWidget_mainWindow->addTab(tab_btrfs, QString());
        tab_subvolumes = new QWidget();
        tab_subvolumes->setObjectName("tab_subvolumes");
        gridLayout_3 = new QGridLayout(tab_subvolumes);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        scrollArea_subvolumes = new QScrollArea(tab_subvolumes);
        scrollArea_subvolumes->setObjectName("scrollArea_subvolumes");
        scrollArea_subvolumes->setFrameShape(QFrame::NoFrame);
        scrollArea_subvolumes->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName("scrollAreaWidgetContents_2");
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 924, 668));
        gridLayout_10 = new QGridLayout(scrollAreaWidgetContents_2);
        gridLayout_10->setObjectName("gridLayout_10");
        horizontalLayout_includeSubvolumes = new QHBoxLayout();
        horizontalLayout_includeSubvolumes->setObjectName("horizontalLayout_includeSubvolumes");
        checkBox_subvolIncludeSnapshots = new QCheckBox(scrollAreaWidgetContents_2);
        checkBox_subvolIncludeSnapshots->setObjectName("checkBox_subvolIncludeSnapshots");
        checkBox_subvolIncludeSnapshots->setChecked(false);

        horizontalLayout_includeSubvolumes->addWidget(checkBox_subvolIncludeSnapshots);

        checkBox_subvolIncludeContainer = new QCheckBox(scrollAreaWidgetContents_2);
        checkBox_subvolIncludeContainer->setObjectName("checkBox_subvolIncludeContainer");
        checkBox_subvolIncludeContainer->setChecked(false);

        horizontalLayout_includeSubvolumes->addWidget(checkBox_subvolIncludeContainer);


        gridLayout_10->addLayout(horizontalLayout_includeSubvolumes, 2, 0, 1, 1);

        frame_subvolumesOptions = new QFrame(scrollAreaWidgetContents_2);
        frame_subvolumesOptions->setObjectName("frame_subvolumesOptions");
        horizontalLayout_9 = new QHBoxLayout(frame_subvolumesOptions);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalLayout_9->setContentsMargins(0, -1, 0, -1);
        lineEdit_subvolFilter = new FilterLineEdit(frame_subvolumesOptions);
        lineEdit_subvolFilter->setObjectName("lineEdit_subvolFilter");

        horizontalLayout_9->addWidget(lineEdit_subvolFilter);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_9);

        toolButton_subvolRestoreBackup = new QToolButton(frame_subvolumesOptions);
        toolButton_subvolRestoreBackup->setObjectName("toolButton_subvolRestoreBackup");
        toolButton_subvolRestoreBackup->setMinimumSize(QSize(100, 0));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/restore.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_subvolRestoreBackup->setIcon(icon);
        toolButton_subvolRestoreBackup->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_9->addWidget(toolButton_subvolRestoreBackup);

        toolButton_subvolumeBrowse = new QToolButton(frame_subvolumesOptions);
        toolButton_subvolumeBrowse->setObjectName("toolButton_subvolumeBrowse");
        toolButton_subvolumeBrowse->setMinimumSize(QSize(100, 0));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/folder.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_subvolumeBrowse->setIcon(icon1);
        toolButton_subvolumeBrowse->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_9->addWidget(toolButton_subvolumeBrowse);

        toolButton_subvolDelete = new QToolButton(frame_subvolumesOptions);
        toolButton_subvolDelete->setObjectName("toolButton_subvolDelete");
        toolButton_subvolDelete->setMinimumSize(QSize(100, 0));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/icons/minus.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_subvolDelete->setIcon(icon2);
        toolButton_subvolDelete->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_9->addWidget(toolButton_subvolDelete);

        toolButton_subvolRefresh = new QToolButton(frame_subvolumesOptions);
        toolButton_subvolRefresh->setObjectName("toolButton_subvolRefresh");
        toolButton_subvolRefresh->setMinimumSize(QSize(100, 0));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/icons/reload.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_subvolRefresh->setIcon(icon3);
        toolButton_subvolRefresh->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_9->addWidget(toolButton_subvolRefresh);


        gridLayout_10->addWidget(frame_subvolumesOptions, 0, 0, 1, 1);

        tableView_subvols = new QTableView(scrollAreaWidgetContents_2);
        tableView_subvols->setObjectName("tableView_subvols");
        tableView_subvols->setSelectionMode(QAbstractItemView::ExtendedSelection);
        tableView_subvols->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableView_subvols->setSortingEnabled(true);
        tableView_subvols->setWordWrap(false);
        tableView_subvols->horizontalHeader()->setStretchLastSection(false);
        tableView_subvols->verticalHeader()->setVisible(false);
        tableView_subvols->verticalHeader()->setStretchLastSection(false);

        gridLayout_10->addWidget(tableView_subvols, 1, 0, 1, 1);

        scrollArea_subvolumes->setWidget(scrollAreaWidgetContents_2);

        gridLayout_3->addWidget(scrollArea_subvolumes, 0, 0, 1, 1);

        tabWidget_mainWindow->addTab(tab_subvolumes, QString());
        tab_snapper_general = new QWidget();
        tab_snapper_general->setObjectName("tab_snapper_general");
        gridLayout_25 = new QGridLayout(tab_snapper_general);
        gridLayout_25->setObjectName("gridLayout_25");
        gridLayout_25->setContentsMargins(4, 4, 4, 4);
        tabWidget_snapper = new QTabWidget(tab_snapper_general);
        tabWidget_snapper->setObjectName("tabWidget_snapper");
        tab_snapperNew = new QWidget();
        tab_snapperNew->setObjectName("tab_snapperNew");
        verticalLayout_4 = new QVBoxLayout(tab_snapperNew);
        verticalLayout_4->setObjectName("verticalLayout_4");
        frame_7 = new QFrame(tab_snapperNew);
        frame_7->setObjectName("frame_7");
        sizePolicy5.setHeightForWidth(frame_7->sizePolicy().hasHeightForWidth());
        frame_7->setSizePolicy(sizePolicy5);
        horizontalLayout_2 = new QHBoxLayout(frame_7);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, -1, 0, -1);
        label_snapperSelect = new QLabel(frame_7);
        label_snapperSelect->setObjectName("label_snapperSelect");

        horizontalLayout_2->addWidget(label_snapperSelect);

        comboBox_snapperConfigs = new QComboBox(frame_7);
        comboBox_snapperConfigs->setObjectName("comboBox_snapperConfigs");
        comboBox_snapperConfigs->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_2->addWidget(comboBox_snapperConfigs);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_8);

        toolButton_snapperCreate = new QToolButton(frame_7);
        toolButton_snapperCreate->setObjectName("toolButton_snapperCreate");
        toolButton_snapperCreate->setMinimumSize(QSize(100, 0));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/icons/plus.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_snapperCreate->setIcon(icon4);
        toolButton_snapperCreate->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_2->addWidget(toolButton_snapperCreate);

        toolButton_snapperDelete = new QToolButton(frame_7);
        toolButton_snapperDelete->setObjectName("toolButton_snapperDelete");
        toolButton_snapperDelete->setMinimumSize(QSize(100, 0));
        toolButton_snapperDelete->setIcon(icon2);
        toolButton_snapperDelete->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_2->addWidget(toolButton_snapperDelete);

        toolButton_snapperNewRefresh = new QToolButton(frame_7);
        toolButton_snapperNewRefresh->setObjectName("toolButton_snapperNewRefresh");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(toolButton_snapperNewRefresh->sizePolicy().hasHeightForWidth());
        toolButton_snapperNewRefresh->setSizePolicy(sizePolicy6);
        toolButton_snapperNewRefresh->setMinimumSize(QSize(100, 0));
        toolButton_snapperNewRefresh->setIcon(icon3);
        toolButton_snapperNewRefresh->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_2->addWidget(toolButton_snapperNewRefresh);


        verticalLayout_4->addWidget(frame_7);

        tableWidget_snapperNew = new QTableWidget(tab_snapperNew);
        tableWidget_snapperNew->setObjectName("tableWidget_snapperNew");
        tableWidget_snapperNew->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget_snapperNew->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableWidget_snapperNew->horizontalHeader()->setCascadingSectionResizes(true);
        tableWidget_snapperNew->horizontalHeader()->setStretchLastSection(true);
        tableWidget_snapperNew->verticalHeader()->setVisible(false);

        verticalLayout_4->addWidget(tableWidget_snapperNew);

        tabWidget_snapper->addTab(tab_snapperNew, QString());
        tab_snapperRestore = new QWidget();
        tab_snapperRestore->setObjectName("tab_snapperRestore");
        verticalLayout_5 = new QVBoxLayout(tab_snapperRestore);
        verticalLayout_5->setObjectName("verticalLayout_5");
        frame = new QFrame(tab_snapperRestore);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout_8 = new QHBoxLayout(frame);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalLayout_8->setContentsMargins(0, -1, 0, -1);
        label_snapperSubvol = new QLabel(frame);
        label_snapperSubvol->setObjectName("label_snapperSubvol");

        horizontalLayout_8->addWidget(label_snapperSubvol);

        comboBox_snapperSubvols = new QComboBox(frame);
        comboBox_snapperSubvols->setObjectName("comboBox_snapperSubvols");

        horizontalLayout_8->addWidget(comboBox_snapperSubvols);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_6);

        toolButton_snapperBrowse = new QToolButton(frame);
        toolButton_snapperBrowse->setObjectName("toolButton_snapperBrowse");
        sizePolicy2.setHeightForWidth(toolButton_snapperBrowse->sizePolicy().hasHeightForWidth());
        toolButton_snapperBrowse->setSizePolicy(sizePolicy2);
        toolButton_snapperBrowse->setMinimumSize(QSize(100, 0));
        toolButton_snapperBrowse->setIcon(icon1);
        toolButton_snapperBrowse->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_8->addWidget(toolButton_snapperBrowse);

        toolButton_snapperRestore = new QToolButton(frame);
        toolButton_snapperRestore->setObjectName("toolButton_snapperRestore");
        toolButton_snapperRestore->setMinimumSize(QSize(100, 0));
        toolButton_snapperRestore->setIcon(icon);
        toolButton_snapperRestore->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_8->addWidget(toolButton_snapperRestore);

        toolButton_snapperRestoreRefresh = new QToolButton(frame);
        toolButton_snapperRestoreRefresh->setObjectName("toolButton_snapperRestoreRefresh");
        sizePolicy6.setHeightForWidth(toolButton_snapperRestoreRefresh->sizePolicy().hasHeightForWidth());
        toolButton_snapperRestoreRefresh->setSizePolicy(sizePolicy6);
        toolButton_snapperRestoreRefresh->setMinimumSize(QSize(100, 0));
        toolButton_snapperRestoreRefresh->setIcon(icon3);
        toolButton_snapperRestoreRefresh->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_8->addWidget(toolButton_snapperRestoreRefresh);


        verticalLayout_5->addWidget(frame);

        tableWidget_snapperRestore = new QTableWidget(tab_snapperRestore);
        tableWidget_snapperRestore->setObjectName("tableWidget_snapperRestore");
        tableWidget_snapperRestore->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget_snapperRestore->setSelectionMode(QAbstractItemView::SingleSelection);
        tableWidget_snapperRestore->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableWidget_snapperRestore->horizontalHeader()->setStretchLastSection(true);
        tableWidget_snapperRestore->verticalHeader()->setVisible(false);

        verticalLayout_5->addWidget(tableWidget_snapperRestore);

        tabWidget_snapper->addTab(tab_snapperRestore, QString());

        gridLayout_25->addWidget(tabWidget_snapper, 0, 0, 1, 1);

        tabWidget_mainWindow->addTab(tab_snapper_general, QString());
        tab_snapper_settings = new QWidget();
        tab_snapper_settings->setObjectName("tab_snapper_settings");
        gridLayout_26 = new QGridLayout(tab_snapper_settings);
        gridLayout_26->setObjectName("gridLayout_26");
        gridLayout_26->setContentsMargins(0, 0, 0, 0);
        scrollArea_snapperSettings = new QScrollArea(tab_snapper_settings);
        scrollArea_snapperSettings->setObjectName("scrollArea_snapperSettings");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(scrollArea_snapperSettings->sizePolicy().hasHeightForWidth());
        scrollArea_snapperSettings->setSizePolicy(sizePolicy7);
        scrollArea_snapperSettings->setFrameShape(QFrame::NoFrame);
        scrollArea_snapperSettings->setWidgetResizable(true);
        scrollAreaWidgetContents_6 = new QWidget();
        scrollAreaWidgetContents_6->setObjectName("scrollAreaWidgetContents_6");
        scrollAreaWidgetContents_6->setGeometry(QRect(0, 0, 924, 668));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents_6);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox_snapperConfigCrud = new QGroupBox(scrollAreaWidgetContents_6);
        groupBox_snapperConfigCrud->setObjectName("groupBox_snapperConfigCrud");
        groupBox_snapperConfigCrud->setTitle(QString::fromUtf8(""));
        horizontalLayout_3 = new QHBoxLayout(groupBox_snapperConfigCrud);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_6 = new QLabel(groupBox_snapperConfigCrud);
        label_6->setObjectName("label_6");

        horizontalLayout_3->addWidget(label_6);

        comboBox_snapperConfigSettings = new QComboBox(groupBox_snapperConfigCrud);
        comboBox_snapperConfigSettings->setObjectName("comboBox_snapperConfigSettings");

        horizontalLayout_3->addWidget(comboBox_snapperConfigSettings);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_10);

        pushButton_snapperNewConfig = new QPushButton(groupBox_snapperConfigCrud);
        pushButton_snapperNewConfig->setObjectName("pushButton_snapperNewConfig");

        horizontalLayout_3->addWidget(pushButton_snapperNewConfig);

        pushButton_snapperDeleteConfig = new QPushButton(groupBox_snapperConfigCrud);
        pushButton_snapperDeleteConfig->setObjectName("pushButton_snapperDeleteConfig");

        horizontalLayout_3->addWidget(pushButton_snapperDeleteConfig);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_11);

        pushButton_snapperSaveConfig = new QPushButton(groupBox_snapperConfigCrud);
        pushButton_snapperSaveConfig->setObjectName("pushButton_snapperSaveConfig");

        horizontalLayout_3->addWidget(pushButton_snapperSaveConfig);


        verticalLayout_2->addWidget(groupBox_snapperConfigCrud);

        groupBox_snapperConfigDisplay = new QGroupBox(scrollAreaWidgetContents_6);
        groupBox_snapperConfigDisplay->setObjectName("groupBox_snapperConfigDisplay");
        horizontalLayout_4 = new QHBoxLayout(groupBox_snapperConfigDisplay);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_snapperConfigName = new QLabel(groupBox_snapperConfigDisplay);
        label_snapperConfigName->setObjectName("label_snapperConfigName");

        horizontalLayout_4->addWidget(label_snapperConfigName);

        label_snapperConfigNameValue = new QLabel(groupBox_snapperConfigDisplay);
        label_snapperConfigNameValue->setObjectName("label_snapperConfigNameValue");
        label_snapperConfigNameValue->setText(QString::fromUtf8(""));

        horizontalLayout_4->addWidget(label_snapperConfigNameValue);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_12);

        label_snapperBackupPath = new QLabel(groupBox_snapperConfigDisplay);
        label_snapperBackupPath->setObjectName("label_snapperBackupPath");

        horizontalLayout_4->addWidget(label_snapperBackupPath);

        label_snapperBackupPathValue = new QLabel(groupBox_snapperConfigDisplay);
        label_snapperBackupPathValue->setObjectName("label_snapperBackupPathValue");
        label_snapperBackupPathValue->setText(QString::fromUtf8(""));

        horizontalLayout_4->addWidget(label_snapperBackupPathValue);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_13);


        verticalLayout_2->addWidget(groupBox_snapperConfigDisplay);

        groupBox_snapperConfigCreate = new QGroupBox(scrollAreaWidgetContents_6);
        groupBox_snapperConfigCreate->setObjectName("groupBox_snapperConfigCreate");
        horizontalLayout_7 = new QHBoxLayout(groupBox_snapperConfigCreate);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_snapperName = new QLabel(groupBox_snapperConfigCreate);
        label_snapperName->setObjectName("label_snapperName");

        horizontalLayout_7->addWidget(label_snapperName);

        lineEdit_snapperName = new QLineEdit(groupBox_snapperConfigCreate);
        lineEdit_snapperName->setObjectName("lineEdit_snapperName");
        lineEdit_snapperName->setMaxLength(20);

        horizontalLayout_7->addWidget(lineEdit_snapperName);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_14);

        label_backupPath = new QLabel(groupBox_snapperConfigCreate);
        label_backupPath->setObjectName("label_backupPath");

        horizontalLayout_7->addWidget(label_backupPath);

        comboBox_snapperPath = new QComboBox(groupBox_snapperConfigCreate);
        comboBox_snapperPath->setObjectName("comboBox_snapperPath");
        comboBox_snapperPath->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_7->addWidget(comboBox_snapperPath);

        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_15);


        verticalLayout_2->addWidget(groupBox_snapperConfigCreate);

        groupBox_snapperConfigSettings = new QGroupBox(scrollAreaWidgetContents_6);
        groupBox_snapperConfigSettings->setObjectName("groupBox_snapperConfigSettings");
        sizePolicy1.setHeightForWidth(groupBox_snapperConfigSettings->sizePolicy().hasHeightForWidth());
        groupBox_snapperConfigSettings->setSizePolicy(sizePolicy1);
        gridLayout_27 = new QGridLayout(groupBox_snapperConfigSettings);
        gridLayout_27->setObjectName("gridLayout_27");
        label_snapperSave4 = new QLabel(groupBox_snapperConfigSettings);
        label_snapperSave4->setObjectName("label_snapperSave4");

        gridLayout_27->addWidget(label_snapperSave4, 4, 1, 1, 1);

        spinBox_snapperYearly = new QSpinBox(groupBox_snapperConfigSettings);
        spinBox_snapperYearly->setObjectName("spinBox_snapperYearly");

        gridLayout_27->addWidget(spinBox_snapperYearly, 5, 2, 1, 1);

        spinBox_snapperHourly = new QSpinBox(groupBox_snapperConfigSettings);
        spinBox_snapperHourly->setObjectName("spinBox_snapperHourly");

        gridLayout_27->addWidget(spinBox_snapperHourly, 1, 2, 1, 1);

        label_snapperEnableTimeline = new QLabel(groupBox_snapperConfigSettings);
        label_snapperEnableTimeline->setObjectName("label_snapperEnableTimeline");

        gridLayout_27->addWidget(label_snapperEnableTimeline, 0, 0, 1, 2);

        label_snapperSave3 = new QLabel(groupBox_snapperConfigSettings);
        label_snapperSave3->setObjectName("label_snapperSave3");

        gridLayout_27->addWidget(label_snapperSave3, 3, 1, 1, 1);

        label_snapperDaily = new QLabel(groupBox_snapperConfigSettings);
        label_snapperDaily->setObjectName("label_snapperDaily");

        gridLayout_27->addWidget(label_snapperDaily, 2, 0, 1, 1);

        label_snapperSave2 = new QLabel(groupBox_snapperConfigSettings);
        label_snapperSave2->setObjectName("label_snapperSave2");

        gridLayout_27->addWidget(label_snapperSave2, 2, 1, 1, 1);

        label_snapperSave5 = new QLabel(groupBox_snapperConfigSettings);
        label_snapperSave5->setObjectName("label_snapperSave5");

        gridLayout_27->addWidget(label_snapperSave5, 5, 1, 1, 1);

        checkBox_snapperEnableTimeline = new QCheckBox(groupBox_snapperConfigSettings);
        checkBox_snapperEnableTimeline->setObjectName("checkBox_snapperEnableTimeline");

        gridLayout_27->addWidget(checkBox_snapperEnableTimeline, 0, 2, 1, 1);

        spinBox_snapperWeekly = new QSpinBox(groupBox_snapperConfigSettings);
        spinBox_snapperWeekly->setObjectName("spinBox_snapperWeekly");

        gridLayout_27->addWidget(spinBox_snapperWeekly, 3, 2, 1, 1);

        spinBox_snapperDaily = new QSpinBox(groupBox_snapperConfigSettings);
        spinBox_snapperDaily->setObjectName("spinBox_snapperDaily");

        gridLayout_27->addWidget(spinBox_snapperDaily, 2, 2, 1, 1);

        spinBox_snapperMonthly = new QSpinBox(groupBox_snapperConfigSettings);
        spinBox_snapperMonthly->setObjectName("spinBox_snapperMonthly");

        gridLayout_27->addWidget(spinBox_snapperMonthly, 4, 2, 1, 1);

        label_snapperYearly = new QLabel(groupBox_snapperConfigSettings);
        label_snapperYearly->setObjectName("label_snapperYearly");

        gridLayout_27->addWidget(label_snapperYearly, 5, 0, 1, 1);

        label_snapperMonthly = new QLabel(groupBox_snapperConfigSettings);
        label_snapperMonthly->setObjectName("label_snapperMonthly");

        gridLayout_27->addWidget(label_snapperMonthly, 4, 0, 1, 1);

        spinBox_snapperNumber = new QSpinBox(groupBox_snapperConfigSettings);
        spinBox_snapperNumber->setObjectName("spinBox_snapperNumber");

        gridLayout_27->addWidget(spinBox_snapperNumber, 6, 2, 1, 1);

        label_snapperHourly = new QLabel(groupBox_snapperConfigSettings);
        label_snapperHourly->setObjectName("label_snapperHourly");

        gridLayout_27->addWidget(label_snapperHourly, 1, 0, 1, 1);

        label_snapperWeekly = new QLabel(groupBox_snapperConfigSettings);
        label_snapperWeekly->setObjectName("label_snapperWeekly");

        gridLayout_27->addWidget(label_snapperWeekly, 3, 0, 1, 1);

        label_snapperSave6 = new QLabel(groupBox_snapperConfigSettings);
        label_snapperSave6->setObjectName("label_snapperSave6");

        gridLayout_27->addWidget(label_snapperSave6, 6, 1, 1, 1);

        label_snapperNumber = new QLabel(groupBox_snapperConfigSettings);
        label_snapperNumber->setObjectName("label_snapperNumber");

        gridLayout_27->addWidget(label_snapperNumber, 6, 0, 1, 1);

        label_snapperSave1 = new QLabel(groupBox_snapperConfigSettings);
        label_snapperSave1->setObjectName("label_snapperSave1");

        gridLayout_27->addWidget(label_snapperSave1, 1, 1, 1, 1);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_27->addItem(horizontalSpacer_16, 2, 3, 1, 1);


        verticalLayout_2->addWidget(groupBox_snapperConfigSettings);

        groupBox_snapperUnits = new QGroupBox(scrollAreaWidgetContents_6);
        groupBox_snapperUnits->setObjectName("groupBox_snapperUnits");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(groupBox_snapperUnits->sizePolicy().hasHeightForWidth());
        groupBox_snapperUnits->setSizePolicy(sizePolicy8);
        horizontalLayout_6 = new QHBoxLayout(groupBox_snapperUnits);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        checkBox_snapperTimeline = new QCheckBox(groupBox_snapperUnits);
        checkBox_snapperTimeline->setObjectName("checkBox_snapperTimeline");
        checkBox_snapperTimeline->setProperty("actionType", QVariant(QString::fromUtf8("service")));
        checkBox_snapperTimeline->setProperty("actionData", QVariant(QString::fromUtf8("snapper-timeline.timer")));

        horizontalLayout_6->addWidget(checkBox_snapperTimeline);

        checkBox_snapperCleanup = new QCheckBox(groupBox_snapperUnits);
        checkBox_snapperCleanup->setObjectName("checkBox_snapperCleanup");
        checkBox_snapperCleanup->setProperty("actionType", QVariant(QString::fromUtf8("service")));
        checkBox_snapperCleanup->setProperty("actionData", QVariant(QString::fromUtf8("snapper-cleanup.timer")));

        horizontalLayout_6->addWidget(checkBox_snapperCleanup);

        checkBox_snapperBoot = new QCheckBox(groupBox_snapperUnits);
        checkBox_snapperBoot->setObjectName("checkBox_snapperBoot");
        checkBox_snapperBoot->setProperty("actionType", QVariant(QString::fromUtf8("service")));
        checkBox_snapperBoot->setProperty("actionData", QVariant(QString::fromUtf8("snapper-boot.timer")));

        horizontalLayout_6->addWidget(checkBox_snapperBoot);

        pushButton_snapperUnitsApply = new QPushButton(groupBox_snapperUnits);
        pushButton_snapperUnitsApply->setObjectName("pushButton_snapperUnitsApply");
        pushButton_snapperUnitsApply->setMaximumSize(QSize(1000, 16777215));

        horizontalLayout_6->addWidget(pushButton_snapperUnitsApply);


        verticalLayout_2->addWidget(groupBox_snapperUnits);

        groupBox_2 = new QGroupBox(scrollAreaWidgetContents_6);
        groupBox_2->setObjectName("groupBox_2");
        sizePolicy1.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy1);

        verticalLayout_2->addWidget(groupBox_2);

        scrollArea_snapperSettings->setWidget(scrollAreaWidgetContents_6);

        gridLayout_26->addWidget(scrollArea_snapperSettings, 1, 0, 1, 1);

        tabWidget_mainWindow->addTab(tab_snapper_settings, QString());
        tab_btrfsmaintenance = new QWidget();
        tab_btrfsmaintenance->setObjectName("tab_btrfsmaintenance");
        gridLayout_2 = new QGridLayout(tab_btrfsmaintenance);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        scrollArea_bm = new QScrollArea(tab_btrfsmaintenance);
        scrollArea_bm->setObjectName("scrollArea_bm");
        scrollArea_bm->setFrameShape(QFrame::NoFrame);
        scrollArea_bm->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 924, 668));
        verticalLayout_3 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_3->setObjectName("verticalLayout_3");
        groupBox_bmBalance = new QGroupBox(scrollAreaWidgetContents);
        groupBox_bmBalance->setObjectName("groupBox_bmBalance");
        sizePolicy1.setHeightForWidth(groupBox_bmBalance->sizePolicy().hasHeightForWidth());
        groupBox_bmBalance->setSizePolicy(sizePolicy1);
        gridLayout_4 = new QGridLayout(groupBox_bmBalance);
        gridLayout_4->setObjectName("gridLayout_4");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer, 1, 2, 1, 1);

        label_bmBalanceFreq = new QLabel(groupBox_bmBalance);
        label_bmBalanceFreq->setObjectName("label_bmBalanceFreq");
        sizePolicy6.setHeightForWidth(label_bmBalanceFreq->sizePolicy().hasHeightForWidth());
        label_bmBalanceFreq->setSizePolicy(sizePolicy6);

        gridLayout_4->addWidget(label_bmBalanceFreq, 1, 0, 1, 1);

        comboBox_bmBalanceFreq = new QComboBox(groupBox_bmBalance);
        comboBox_bmBalanceFreq->setObjectName("comboBox_bmBalanceFreq");

        gridLayout_4->addWidget(comboBox_bmBalanceFreq, 1, 1, 1, 1);

        checkBox_bmBalance = new QCheckBox(groupBox_bmBalance);
        checkBox_bmBalance->setObjectName("checkBox_bmBalance");

        gridLayout_4->addWidget(checkBox_bmBalance, 0, 4, 1, 1);

        label_bmBalanceSubvols = new QLabel(groupBox_bmBalance);
        label_bmBalanceSubvols->setObjectName("label_bmBalanceSubvols");

        gridLayout_4->addWidget(label_bmBalanceSubvols, 0, 3, 1, 1);

        listWidget_bmBalance = new QListWidget(groupBox_bmBalance);
        listWidget_bmBalance->setObjectName("listWidget_bmBalance");
        QSizePolicy sizePolicy9(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(listWidget_bmBalance->sizePolicy().hasHeightForWidth());
        listWidget_bmBalance->setSizePolicy(sizePolicy9);
        listWidget_bmBalance->setSelectionMode(QAbstractItemView::MultiSelection);

        gridLayout_4->addWidget(listWidget_bmBalance, 1, 4, 1, 1);


        verticalLayout_3->addWidget(groupBox_bmBalance);

        groupBox_bmScrub = new QGroupBox(scrollAreaWidgetContents);
        groupBox_bmScrub->setObjectName("groupBox_bmScrub");
        sizePolicy1.setHeightForWidth(groupBox_bmScrub->sizePolicy().hasHeightForWidth());
        groupBox_bmScrub->setSizePolicy(sizePolicy1);
        gridLayout_5 = new QGridLayout(groupBox_bmScrub);
        gridLayout_5->setObjectName("gridLayout_5");
        comboBox_bmScrubFreq = new QComboBox(groupBox_bmScrub);
        comboBox_bmScrubFreq->setObjectName("comboBox_bmScrubFreq");

        gridLayout_5->addWidget(comboBox_bmScrubFreq, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        listWidget_bmScrub = new QListWidget(groupBox_bmScrub);
        listWidget_bmScrub->setObjectName("listWidget_bmScrub");
        sizePolicy9.setHeightForWidth(listWidget_bmScrub->sizePolicy().hasHeightForWidth());
        listWidget_bmScrub->setSizePolicy(sizePolicy9);
        listWidget_bmScrub->setSelectionMode(QAbstractItemView::MultiSelection);

        gridLayout_5->addWidget(listWidget_bmScrub, 1, 4, 1, 1);

        label_bmScrubFreq = new QLabel(groupBox_bmScrub);
        label_bmScrubFreq->setObjectName("label_bmScrubFreq");
        sizePolicy6.setHeightForWidth(label_bmScrubFreq->sizePolicy().hasHeightForWidth());
        label_bmScrubFreq->setSizePolicy(sizePolicy6);

        gridLayout_5->addWidget(label_bmScrubFreq, 1, 0, 1, 1);

        checkBox_bmScrub = new QCheckBox(groupBox_bmScrub);
        checkBox_bmScrub->setObjectName("checkBox_bmScrub");

        gridLayout_5->addWidget(checkBox_bmScrub, 0, 4, 1, 1);

        label_bmScrubSubvols = new QLabel(groupBox_bmScrub);
        label_bmScrubSubvols->setObjectName("label_bmScrubSubvols");

        gridLayout_5->addWidget(label_bmScrubSubvols, 0, 3, 1, 1);


        verticalLayout_3->addWidget(groupBox_bmScrub);

        groupBox_bmDefrag = new QGroupBox(scrollAreaWidgetContents);
        groupBox_bmDefrag->setObjectName("groupBox_bmDefrag");
        sizePolicy1.setHeightForWidth(groupBox_bmDefrag->sizePolicy().hasHeightForWidth());
        groupBox_bmDefrag->setSizePolicy(sizePolicy1);
        gridLayout_6 = new QGridLayout(groupBox_bmDefrag);
        gridLayout_6->setObjectName("gridLayout_6");
        comboBox_bmDefragFreq = new QComboBox(groupBox_bmDefrag);
        comboBox_bmDefragFreq->setObjectName("comboBox_bmDefragFreq");

        gridLayout_6->addWidget(comboBox_bmDefragFreq, 1, 1, 1, 1);

        listWidget_bmDefrag = new QListWidget(groupBox_bmDefrag);
        listWidget_bmDefrag->setObjectName("listWidget_bmDefrag");
        sizePolicy9.setHeightForWidth(listWidget_bmDefrag->sizePolicy().hasHeightForWidth());
        listWidget_bmDefrag->setSizePolicy(sizePolicy9);
        listWidget_bmDefrag->setSelectionMode(QAbstractItemView::MultiSelection);

        gridLayout_6->addWidget(listWidget_bmDefrag, 1, 5, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_3, 1, 2, 1, 1);

        label_bmDefragFreq = new QLabel(groupBox_bmDefrag);
        label_bmDefragFreq->setObjectName("label_bmDefragFreq");
        sizePolicy6.setHeightForWidth(label_bmDefragFreq->sizePolicy().hasHeightForWidth());
        label_bmDefragFreq->setSizePolicy(sizePolicy6);

        gridLayout_6->addWidget(label_bmDefragFreq, 1, 0, 1, 1);

        checkBox_bmDefrag = new QCheckBox(groupBox_bmDefrag);
        checkBox_bmDefrag->setObjectName("checkBox_bmDefrag");

        gridLayout_6->addWidget(checkBox_bmDefrag, 0, 5, 1, 1);

        label_bmScrubSubvols_2 = new QLabel(groupBox_bmDefrag);
        label_bmScrubSubvols_2->setObjectName("label_bmScrubSubvols_2");

        gridLayout_6->addWidget(label_bmScrubSubvols_2, 0, 3, 1, 1);


        verticalLayout_3->addWidget(groupBox_bmDefrag);

        frame_bmApply = new QFrame(scrollAreaWidgetContents);
        frame_bmApply->setObjectName("frame_bmApply");
        sizePolicy5.setHeightForWidth(frame_bmApply->sizePolicy().hasHeightForWidth());
        frame_bmApply->setSizePolicy(sizePolicy5);
        horizontalLayout_5 = new QHBoxLayout(frame_bmApply);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_4 = new QSpacerItem(739, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);

        toolButton_bmReset = new QToolButton(frame_bmApply);
        toolButton_bmReset->setObjectName("toolButton_bmReset");
        toolButton_bmReset->setMinimumSize(QSize(100, 0));
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/icons/reset.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_bmReset->setIcon(icon5);
        toolButton_bmReset->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_5->addWidget(toolButton_bmReset);

        toolButton_bmApply = new QToolButton(frame_bmApply);
        toolButton_bmApply->setObjectName("toolButton_bmApply");
        toolButton_bmApply->setMinimumSize(QSize(100, 0));
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/icons/checkmark.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        toolButton_bmApply->setIcon(icon6);
        toolButton_bmApply->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);

        horizontalLayout_5->addWidget(toolButton_bmApply);


        verticalLayout_3->addWidget(frame_bmApply);

        scrollArea_bm->setWidget(scrollAreaWidgetContents);

        gridLayout_2->addWidget(scrollArea_bm, 0, 0, 1, 1);

        tabWidget_mainWindow->addTab(tab_btrfsmaintenance, QString());

        gridLayout->addWidget(tabWidget_mainWindow, 0, 0, 1, 1);

        MainWindow->setCentralWidget(centralwidget);

        retranslateUi(MainWindow);

        tabWidget_mainWindow->setCurrentIndex(0);
        tabWidget_snapper->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QCoreApplication::translate("MainWindow", "BTRFS-Assistant", nullptr));
        groupBox_btrfsSrubOperation->setTitle(QCoreApplication::translate("MainWindow", "Scrub", nullptr));
#if QT_CONFIG(tooltip)
        pushButton_btrfsScrub->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Perform scrub on device.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton_btrfsScrub->setText(QCoreApplication::translate("MainWindow", "Start", nullptr));
        label_btrfsScrubStatus->setText(QCoreApplication::translate("MainWindow", "No scrub ran.", nullptr));
        groupBox_btrfsBalanceOperation->setTitle(QCoreApplication::translate("MainWindow", "Balance", nullptr));
#if QT_CONFIG(tooltip)
        pushButton_btrfsBalance->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Perform full balance on device.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton_btrfsBalance->setText(QCoreApplication::translate("MainWindow", "Start", nullptr));
        label_btrfsBalanceStatus->setText(QCoreApplication::translate("MainWindow", "No balance ran.", nullptr));
        groupBox_btrfsFilesystemStats->setTitle(QCoreApplication::translate("MainWindow", "Internal Filesystem Statistics", nullptr));
#if QT_CONFIG(tooltip)
        progressBar_btrfssys->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Utilization percentage of system chunks in the allocated space.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_btrfsdata->setText(QCoreApplication::translate("MainWindow", "Data:", nullptr));
        label_btrfsmeta->setText(QCoreApplication::translate("MainWindow", "Metadata:", nullptr));
        label_btrfssys->setText(QCoreApplication::translate("MainWindow", "System:", nullptr));
#if QT_CONFIG(tooltip)
        progressBar_btrfsmeta->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Utilization percentage of metadata chunks in the allocated space.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        progressBar_btrfsdata->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Utilization percentage of file data chunks in the allocated space.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_btrfsInfo->setTitle(QCoreApplication::translate("MainWindow", "Information", nullptr));
        label_btrfsUsed->setText(QCoreApplication::translate("MainWindow", "Used:", nullptr));
#if QT_CONFIG(tooltip)
        label_btrfsFreeValue->setToolTip(QCoreApplication::translate("MainWindow", "Estimate of the amount of data that can still be written to this FS, based on the current usage profile.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_btrfsFreeValue->setText(QString());
#if QT_CONFIG(tooltip)
        label_btrfsFreeMinValue->setToolTip(QCoreApplication::translate("MainWindow", "Minimum amount of data that you can expect to be able to get onto the filesystem. ", nullptr));
#endif // QT_CONFIG(tooltip)
        label_btrfsFreeMinValue->setText(QString());
        label_btrfsAllocatedValue->setText(QString());
        label_btrfsAllocated->setText(QCoreApplication::translate("MainWindow", "Allocated:  ", nullptr));
        label_btrfsSizeValue->setText(QString());
        label_btrfsSize->setText(QCoreApplication::translate("MainWindow", "Filesystem Size: ", nullptr));
        label_btrfsMessage->setText(QString());
#if QT_CONFIG(tooltip)
        label_btrfsFree->setToolTip(QCoreApplication::translate("MainWindow", "Estimate of the amount of data that can still be written to this FS, based on the current usage profile.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_btrfsFree->setText(QCoreApplication::translate("MainWindow", "Free (Estimated): ", nullptr));
#if QT_CONFIG(tooltip)
        label_btrfsFreeMin->setToolTip(QCoreApplication::translate("MainWindow", "Minimum amount of data that you can expect to be able to get onto the filesystem. ", nullptr));
#endif // QT_CONFIG(tooltip)
        label_btrfsFreeMin->setText(QCoreApplication::translate("MainWindow", "Free (Minimum): ", nullptr));
        groupBox_deviceSelection->setTitle(QCoreApplication::translate("MainWindow", "Volume Selection", nullptr));
        label_btrfsDevice->setText(QCoreApplication::translate("MainWindow", "Filesystem:", nullptr));
        comboBox_btrfsDevice->setCurrentText(QString());
        comboBox_btrfsDevice->setPlaceholderText(QString());
        pushButton_enableQuota->setText(QCoreApplication::translate("MainWindow", "Enable Quotas", nullptr));
        pushButton_btrfsRefreshData->setText(QCoreApplication::translate("MainWindow", "Refresh Btrfs Data", nullptr));
        tabWidget_mainWindow->setTabText(tabWidget_mainWindow->indexOf(tab_btrfs), QCoreApplication::translate("MainWindow", "Overview", nullptr));
#if QT_CONFIG(tooltip)
        checkBox_subvolIncludeSnapshots->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Include children subvolumes of .snapshots and timeshift folders.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBox_subvolIncludeSnapshots->setText(QCoreApplication::translate("MainWindow", "Include Timeshift and Snapper Snapshots", nullptr));
        checkBox_subvolIncludeContainer->setText(QCoreApplication::translate("MainWindow", "Include Container Subvolumes", nullptr));
        lineEdit_subvolFilter->setPlaceholderText(QCoreApplication::translate("MainWindow", "Filter...", nullptr));
        toolButton_subvolRestoreBackup->setText(QCoreApplication::translate("MainWindow", "Restore Backup", nullptr));
        toolButton_subvolumeBrowse->setText(QCoreApplication::translate("MainWindow", "Browse", nullptr));
        toolButton_subvolDelete->setText(QCoreApplication::translate("MainWindow", "Delete", nullptr));
        toolButton_subvolRefresh->setText(QCoreApplication::translate("MainWindow", "Refresh", nullptr));
        tabWidget_mainWindow->setTabText(tabWidget_mainWindow->indexOf(tab_subvolumes), QCoreApplication::translate("MainWindow", "Subvolumes", nullptr));
        label_snapperSelect->setText(QCoreApplication::translate("MainWindow", "Select config: ", nullptr));
        toolButton_snapperCreate->setText(QCoreApplication::translate("MainWindow", "New", nullptr));
        toolButton_snapperDelete->setText(QCoreApplication::translate("MainWindow", "Delete", nullptr));
        toolButton_snapperNewRefresh->setText(QCoreApplication::translate("MainWindow", "Refresh", nullptr));
        tabWidget_snapper->setTabText(tabWidget_snapper->indexOf(tab_snapperNew), QCoreApplication::translate("MainWindow", "New/Delete", nullptr));
        label_snapperSubvol->setText(QCoreApplication::translate("MainWindow", "Select target: ", nullptr));
        toolButton_snapperBrowse->setText(QCoreApplication::translate("MainWindow", "Browse", nullptr));
        toolButton_snapperRestore->setText(QCoreApplication::translate("MainWindow", "Restore", nullptr));
        toolButton_snapperRestoreRefresh->setText(QCoreApplication::translate("MainWindow", "Refresh", nullptr));
        tabWidget_snapper->setTabText(tabWidget_snapper->indexOf(tab_snapperRestore), QCoreApplication::translate("MainWindow", "Browse/Restore", nullptr));
        tabWidget_mainWindow->setTabText(tabWidget_mainWindow->indexOf(tab_snapper_general), QCoreApplication::translate("MainWindow", "Snapper", nullptr));
        label_6->setText(QCoreApplication::translate("MainWindow", "Select config: ", nullptr));
        pushButton_snapperNewConfig->setText(QCoreApplication::translate("MainWindow", "New", nullptr));
        pushButton_snapperDeleteConfig->setText(QCoreApplication::translate("MainWindow", "Delete", nullptr));
        pushButton_snapperSaveConfig->setText(QCoreApplication::translate("MainWindow", "Save", nullptr));
        groupBox_snapperConfigDisplay->setTitle(QCoreApplication::translate("MainWindow", "Config Information", nullptr));
        label_snapperConfigName->setText(QCoreApplication::translate("MainWindow", "Config name: ", nullptr));
        label_snapperBackupPath->setText(QCoreApplication::translate("MainWindow", "Backup path: ", nullptr));
        groupBox_snapperConfigCreate->setTitle(QCoreApplication::translate("MainWindow", "Config Information", nullptr));
        label_snapperName->setText(QCoreApplication::translate("MainWindow", "Config name: ", nullptr));
        label_backupPath->setText(QCoreApplication::translate("MainWindow", "Backup path: ", nullptr));
        groupBox_snapperConfigSettings->setTitle(QCoreApplication::translate("MainWindow", "Snapshot Retention", nullptr));
        label_snapperSave4->setText(QCoreApplication::translate("MainWindow", "Save: ", nullptr));
#if QT_CONFIG(tooltip)
        label_snapperEnableTimeline->setToolTip(QCoreApplication::translate("MainWindow", "Timeline snapshots are taken hourly, the cleanup job reduces the snapshots in accordance with the below settings", nullptr));
#endif // QT_CONFIG(tooltip)
        label_snapperEnableTimeline->setText(QCoreApplication::translate("MainWindow", "Enable timeline snapshots", nullptr));
        label_snapperSave3->setText(QCoreApplication::translate("MainWindow", "Save: ", nullptr));
        label_snapperDaily->setText(QCoreApplication::translate("MainWindow", "Daily", nullptr));
        label_snapperSave2->setText(QCoreApplication::translate("MainWindow", "Save: ", nullptr));
        label_snapperSave5->setText(QCoreApplication::translate("MainWindow", "Save: ", nullptr));
#if QT_CONFIG(tooltip)
        checkBox_snapperEnableTimeline->setToolTip(QCoreApplication::translate("MainWindow", "Timeline snapshots are taken hourly, the cleanup job reduces the snapshots in accordance with the below settings", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBox_snapperEnableTimeline->setText(QString());
        label_snapperYearly->setText(QCoreApplication::translate("MainWindow", "Yearly", nullptr));
        label_snapperMonthly->setText(QCoreApplication::translate("MainWindow", "Monthly", nullptr));
        label_snapperHourly->setText(QCoreApplication::translate("MainWindow", "Hourly", nullptr));
        label_snapperWeekly->setText(QCoreApplication::translate("MainWindow", "Weekly", nullptr));
        label_snapperSave6->setText(QCoreApplication::translate("MainWindow", "Save:", nullptr));
        label_snapperNumber->setText(QCoreApplication::translate("MainWindow", "Number", nullptr));
        label_snapperSave1->setText(QCoreApplication::translate("MainWindow", "Save: ", nullptr));
        groupBox_snapperUnits->setTitle(QCoreApplication::translate("MainWindow", "systemd Unit Settings", nullptr));
        checkBox_snapperTimeline->setText(QCoreApplication::translate("MainWindow", "Snapper timeline enabled", nullptr));
        checkBox_snapperCleanup->setText(QCoreApplication::translate("MainWindow", "Snapper cleanup enabled", nullptr));
        checkBox_snapperBoot->setText(QCoreApplication::translate("MainWindow", "Snapper boot enabled", nullptr));
        pushButton_snapperUnitsApply->setText(QCoreApplication::translate("MainWindow", "Apply systemd changes", nullptr));
        groupBox_2->setTitle(QString());
        tabWidget_mainWindow->setTabText(tabWidget_mainWindow->indexOf(tab_snapper_settings), QCoreApplication::translate("MainWindow", "Snapper Settings", nullptr));
        groupBox_bmBalance->setTitle(QCoreApplication::translate("MainWindow", "Balance", nullptr));
        label_bmBalanceFreq->setText(QCoreApplication::translate("MainWindow", "Frequency: ", nullptr));
        checkBox_bmBalance->setText(QCoreApplication::translate("MainWindow", "Select All", nullptr));
        label_bmBalanceSubvols->setText(QCoreApplication::translate("MainWindow", "Mountpoints: ", nullptr));
        groupBox_bmScrub->setTitle(QCoreApplication::translate("MainWindow", "Scrub", nullptr));
        label_bmScrubFreq->setText(QCoreApplication::translate("MainWindow", "Frequency: ", nullptr));
        checkBox_bmScrub->setText(QCoreApplication::translate("MainWindow", "Select All", nullptr));
        label_bmScrubSubvols->setText(QCoreApplication::translate("MainWindow", "Mountpoints: ", nullptr));
        groupBox_bmDefrag->setTitle(QCoreApplication::translate("MainWindow", "Defrag", nullptr));
        label_bmDefragFreq->setText(QCoreApplication::translate("MainWindow", "Frequency: ", nullptr));
        checkBox_bmDefrag->setText(QCoreApplication::translate("MainWindow", "Select All", nullptr));
        label_bmScrubSubvols_2->setText(QCoreApplication::translate("MainWindow", "Mountpoints: ", nullptr));
        toolButton_bmReset->setText(QCoreApplication::translate("MainWindow", "Reset", nullptr));
#if QT_CONFIG(tooltip)
        toolButton_bmApply->setToolTip(QCoreApplication::translate("MainWindow", "<html><head/><body><p>Update Btrfs Maintenance config file and call service to load new settings.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButton_bmApply->setText(QCoreApplication::translate("MainWindow", "Apply", nullptr));
        tabWidget_mainWindow->setTabText(tabWidget_mainWindow->indexOf(tab_btrfsmaintenance), QCoreApplication::translate("MainWindow", "Btrfs maintenance", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
