/********************************************************************************
** Form generated from reading UI file 'RestoreConfirmDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESTORECONFIRMDIALOG_H
#define UI_RESTORECONFIRMDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_RestoreConfirmDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *questionLabel;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLabel *backupNameLabel;
    QLineEdit *backupNameLineEdit;
    QFrame *buttonsFrame;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushButton_yes;
    QPushButton *pushButton_no;

    void setupUi(QDialog *RestoreConfirmDialog)
    {
        if (RestoreConfirmDialog->objectName().isEmpty())
            RestoreConfirmDialog->setObjectName("RestoreConfirmDialog");
        RestoreConfirmDialog->resize(423, 146);
        verticalLayout = new QVBoxLayout(RestoreConfirmDialog);
        verticalLayout->setObjectName("verticalLayout");
        questionLabel = new QLabel(RestoreConfirmDialog);
        questionLabel->setObjectName("questionLabel");

        verticalLayout->addWidget(questionLabel);

        frame = new QFrame(RestoreConfirmDialog);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, -1, 0, -1);
        backupNameLabel = new QLabel(frame);
        backupNameLabel->setObjectName("backupNameLabel");

        horizontalLayout->addWidget(backupNameLabel);

        backupNameLineEdit = new QLineEdit(frame);
        backupNameLineEdit->setObjectName("backupNameLineEdit");

        horizontalLayout->addWidget(backupNameLineEdit);


        verticalLayout->addWidget(frame);

        buttonsFrame = new QFrame(RestoreConfirmDialog);
        buttonsFrame->setObjectName("buttonsFrame");
        buttonsFrame->setFrameShape(QFrame::NoFrame);
        buttonsFrame->setFrameShadow(QFrame::Raised);
        horizontalLayout_2 = new QHBoxLayout(buttonsFrame);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, -1, 0, -1);
        horizontalSpacer = new QSpacerItem(221, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        pushButton_yes = new QPushButton(buttonsFrame);
        pushButton_yes->setObjectName("pushButton_yes");

        horizontalLayout_2->addWidget(pushButton_yes);

        pushButton_no = new QPushButton(buttonsFrame);
        pushButton_no->setObjectName("pushButton_no");

        horizontalLayout_2->addWidget(pushButton_no);


        verticalLayout->addWidget(buttonsFrame);


        retranslateUi(RestoreConfirmDialog);

        QMetaObject::connectSlotsByName(RestoreConfirmDialog);
    } // setupUi

    void retranslateUi(QDialog *RestoreConfirmDialog)
    {
        RestoreConfirmDialog->setWindowTitle(QCoreApplication::translate("RestoreConfirmDialog", "Dialog", nullptr));
        questionLabel->setText(QString());
        backupNameLabel->setText(QCoreApplication::translate("RestoreConfirmDialog", "Name for saved backup(Optional): ", nullptr));
        pushButton_yes->setText(QCoreApplication::translate("RestoreConfirmDialog", "Yes", nullptr));
        pushButton_no->setText(QCoreApplication::translate("RestoreConfirmDialog", "No", nullptr));
#if QT_CONFIG(shortcut)
        pushButton_no->setShortcut(QCoreApplication::translate("RestoreConfirmDialog", "Ctrl+R", nullptr));
#endif // QT_CONFIG(shortcut)
    } // retranslateUi

};

namespace Ui {
    class RestoreConfirmDialog: public Ui_RestoreConfirmDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_RESTORECONFIRMDIALOG_H
