/********************************************************************************
** Form generated from reading UI file 'SnapshotSubvolumeDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SNAPSHOTSUBVOLUMEDIALOG_H
#define UI_SNAPSHOTSUBVOLUMEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_SnapshotSubvolumeDialog
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QLineEdit *destinationLineEdit;
    QPushButton *browseButton;
    QCheckBox *readOnlyCheckBox;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SnapshotSubvolumeDialog)
    {
        if (SnapshotSubvolumeDialog->objectName().isEmpty())
            SnapshotSubvolumeDialog->setObjectName("SnapshotSubvolumeDialog");
        SnapshotSubvolumeDialog->resize(558, 123);
        formLayout = new QFormLayout(SnapshotSubvolumeDialog);
        formLayout->setObjectName("formLayout");
        label = new QLabel(SnapshotSubvolumeDialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        destinationLineEdit = new QLineEdit(SnapshotSubvolumeDialog);
        destinationLineEdit->setObjectName("destinationLineEdit");

        horizontalLayout->addWidget(destinationLineEdit);

        browseButton = new QPushButton(SnapshotSubvolumeDialog);
        browseButton->setObjectName("browseButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(browseButton->sizePolicy().hasHeightForWidth());
        browseButton->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(browseButton);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        readOnlyCheckBox = new QCheckBox(SnapshotSubvolumeDialog);
        readOnlyCheckBox->setObjectName("readOnlyCheckBox");
        readOnlyCheckBox->setChecked(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, readOnlyCheckBox);

        buttonBox = new QDialogButtonBox(SnapshotSubvolumeDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, buttonBox);


        retranslateUi(SnapshotSubvolumeDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SnapshotSubvolumeDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SnapshotSubvolumeDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SnapshotSubvolumeDialog);
    } // setupUi

    void retranslateUi(QDialog *SnapshotSubvolumeDialog)
    {
        SnapshotSubvolumeDialog->setWindowTitle(QCoreApplication::translate("SnapshotSubvolumeDialog", "Create a snapshot", nullptr));
        label->setText(QCoreApplication::translate("SnapshotSubvolumeDialog", "Destination:", nullptr));
        destinationLineEdit->setPlaceholderText(QCoreApplication::translate("SnapshotSubvolumeDialog", "A filesystem path", nullptr));
        browseButton->setText(QCoreApplication::translate("SnapshotSubvolumeDialog", "Browse...", nullptr));
        readOnlyCheckBox->setText(QCoreApplication::translate("SnapshotSubvolumeDialog", "Read-only", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SnapshotSubvolumeDialog: public Ui_SnapshotSubvolumeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SNAPSHOTSUBVOLUMEDIALOG_H
