/********************************************************************************
** Form generated from reading UI file 'DiffViewer.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIFFVIEWER_H
#define UI_DIFFVIEWER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DiffViewer
{
public:
    QVBoxLayout *verticalLayout;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QHBoxLayout *horizontalLayout_2;
    QTableWidget *tableWidget_snapshotList;
    QTextEdit *textEdit_diff;
    QFrame *frame_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushButton_restore;
    QPushButton *pushButton_close;

    void setupUi(QDialog *DiffViewer)
    {
        if (DiffViewer->objectName().isEmpty())
            DiffViewer->setObjectName("DiffViewer");
        DiffViewer->resize(1050, 613);
        verticalLayout = new QVBoxLayout(DiffViewer);
        verticalLayout->setObjectName("verticalLayout");
        scrollArea = new QScrollArea(DiffViewer);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 1030, 544));
        horizontalLayout_2 = new QHBoxLayout(scrollAreaWidgetContents);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        tableWidget_snapshotList = new QTableWidget(scrollAreaWidgetContents);
        tableWidget_snapshotList->setObjectName("tableWidget_snapshotList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tableWidget_snapshotList->sizePolicy().hasHeightForWidth());
        tableWidget_snapshotList->setSizePolicy(sizePolicy);
        tableWidget_snapshotList->setSelectionMode(QAbstractItemView::SingleSelection);
        tableWidget_snapshotList->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableWidget_snapshotList->setShowGrid(false);
        tableWidget_snapshotList->setWordWrap(false);
        tableWidget_snapshotList->setCornerButtonEnabled(false);
        tableWidget_snapshotList->horizontalHeader()->setVisible(false);
        tableWidget_snapshotList->horizontalHeader()->setStretchLastSection(true);
        tableWidget_snapshotList->verticalHeader()->setVisible(false);

        horizontalLayout_2->addWidget(tableWidget_snapshotList);

        textEdit_diff = new QTextEdit(scrollAreaWidgetContents);
        textEdit_diff->setObjectName("textEdit_diff");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(textEdit_diff->sizePolicy().hasHeightForWidth());
        textEdit_diff->setSizePolicy(sizePolicy1);
        QFont font;
        font.setFamilies({QString::fromUtf8("Bitstream Vera Sans Mono")});
        textEdit_diff->setFont(font);
        textEdit_diff->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        horizontalLayout_2->addWidget(textEdit_diff);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout->addWidget(scrollArea);

        frame_2 = new QFrame(DiffViewer);
        frame_2->setObjectName("frame_2");
        frame_2->setFrameShape(QFrame::NoFrame);
        frame_2->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame_2);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pushButton_restore = new QPushButton(frame_2);
        pushButton_restore->setObjectName("pushButton_restore");

        horizontalLayout->addWidget(pushButton_restore);

        pushButton_close = new QPushButton(frame_2);
        pushButton_close->setObjectName("pushButton_close");

        horizontalLayout->addWidget(pushButton_close);


        verticalLayout->addWidget(frame_2);


        retranslateUi(DiffViewer);

        QMetaObject::connectSlotsByName(DiffViewer);
    } // setupUi

    void retranslateUi(QDialog *DiffViewer)
    {
        DiffViewer->setWindowTitle(QCoreApplication::translate("DiffViewer", "Dialog", nullptr));
        textEdit_diff->setPlaceholderText(QCoreApplication::translate("DiffViewer", "Select a snapshot from the left to see the diff", nullptr));
        pushButton_restore->setText(QCoreApplication::translate("DiffViewer", "Restore", nullptr));
        pushButton_close->setText(QCoreApplication::translate("DiffViewer", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DiffViewer: public Ui_DiffViewer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIFFVIEWER_H
