/********************************************************************************
** Form generated from reading UI file 'FileBrowser.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILEBROWSER_H
#define UI_FILEBROWSER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_FileBrowser
{
public:
    QVBoxLayout *verticalLayout;
    QTreeView *treeView_file;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushButton_diff;
    QPushButton *pushButton_restore;
    QPushButton *pushButton_close;

    void setupUi(QDialog *FileBrowser)
    {
        if (FileBrowser->objectName().isEmpty())
            FileBrowser->setObjectName("FileBrowser");
        FileBrowser->resize(630, 529);
        verticalLayout = new QVBoxLayout(FileBrowser);
        verticalLayout->setObjectName("verticalLayout");
        treeView_file = new QTreeView(FileBrowser);
        treeView_file->setObjectName("treeView_file");
        treeView_file->setUniformRowHeights(true);
        treeView_file->setSortingEnabled(true);

        verticalLayout->addWidget(treeView_file);

        frame = new QFrame(FileBrowser);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy);
        frame->setMinimumSize(QSize(0, 50));
        frame->setFrameShape(QFrame::NoFrame);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pushButton_diff = new QPushButton(frame);
        pushButton_diff->setObjectName("pushButton_diff");
        sizePolicy.setHeightForWidth(pushButton_diff->sizePolicy().hasHeightForWidth());
        pushButton_diff->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(pushButton_diff);

        pushButton_restore = new QPushButton(frame);
        pushButton_restore->setObjectName("pushButton_restore");
        sizePolicy.setHeightForWidth(pushButton_restore->sizePolicy().hasHeightForWidth());
        pushButton_restore->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(pushButton_restore);

        pushButton_close = new QPushButton(frame);
        pushButton_close->setObjectName("pushButton_close");
        sizePolicy.setHeightForWidth(pushButton_close->sizePolicy().hasHeightForWidth());
        pushButton_close->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(pushButton_close);


        verticalLayout->addWidget(frame);


        retranslateUi(FileBrowser);

        QMetaObject::connectSlotsByName(FileBrowser);
    } // setupUi

    void retranslateUi(QDialog *FileBrowser)
    {
        FileBrowser->setWindowTitle(QCoreApplication::translate("FileBrowser", "Dialog", nullptr));
        pushButton_diff->setText(QCoreApplication::translate("FileBrowser", "Show Diff", nullptr));
        pushButton_restore->setText(QCoreApplication::translate("FileBrowser", "Restore File", nullptr));
        pushButton_close->setText(QCoreApplication::translate("FileBrowser", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FileBrowser: public Ui_FileBrowser {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FILEBROWSER_H
